 /*+-------------------------------------------------------------+
   |          S A S   S A M P L E   L I B R A R Y                |
   |                                                             |
   |    NAME: GEOCITY                                            |
   |   TITLE: GEOCITY- U.S. City Geocoding                       |
   | PRODUCT: GRAPH                                              |
   |  SYSTEM: ALL                                                |
   |    KEYS: GRAPHICS MAPS GEOCODE                              |
   |   PROCS: GEOCODE                                            |
   |    DATA: EXTERNAL                                           |
   |                                                             |
   | SUPPORT: GRAPHICS STAFF              CREATED: 13FEB2011     |
   |  UPDATE: 04MAR2015 - removed quit per customer request      |
   |     REF: SAS/GRAPH AND BASE SAS MAPPING REFERENCE           |
   +-------------------------------------------------------------+*/

/* Generate the TRAINING input data set that the GEOCODE procedure
   uses. */
data training (label='Selected SAS training locations in USA');
  infile datalines dlm=',';
  length city  $ 24 
         state $ 2;
  input city   /* City name                         */
        state; /* Two-character postal abbreviation */
datalines;
Atlanta, GA
Bedminster, NJ
Cary, NC
Chicago, IL
Dayton, OH
Des Moines, IA
Detroit, MI
Hartford, CT
Miami, FL
Middleton, MA
Minneapolis, MN
New York, NY
Overland Park, KS
Philadelphia, PA
Phoenix, AZ
San Antonio, TX
San Francisco, CA
Seattle, WA
;
run;

/* Run the GEOCODE procedure with the generated TRAINING input data
   set. Specify the CITY method to add the latitude and longitude
   geographic coordinate values from the lookup data set to the
   addresses in the input data set. Those values are output to the
   GEOCODED_TRAINING data set. The default lookup data set is
   MAPSGFK.USCITY_ALL. */
proc geocode       
  method=city               /* Specify geocoding method       */
  data=training             /* Input data set of cities       */
  out=geocoded_training;    /* Output data set with locations */
run;

/* Print the entire GEOCODED_TRAINING output data set, suppressing
   the observation column. */
proc print data=geocoded_training noobs;
run;
