 /*+-------------------------------------------------------------+
   |          S A S   S A M P L E   L I B R A R Y                |
   |                                                             |
   |    NAME: GEOZIPUK                                           |
   |   TITLE: GEOZIPUK-British Postcode Geocoding                |
   | PRODUCT: GRAPH                                              |
   |  SYSTEM: ALL                                                |
   |    KEYS: GRAPHICS MAPS GEOCODE                              |
   |   PROCS: GEOCODE                                            |
   |    DATA: EXTERNAL                                           |
   |                                                             |
   | SUPPORT: GRAPHICS STAFF              CREATED: 06JUL2012     |
   |  UPDATE: 09APR2013 - Removed specialized variable names so  |
   |            that world city geocoding could be run with the  |
   |            same var names                                   |
   |          04MAR2015 - removed quit per customer request      |
   |          21APR2015 - added semi-colon after country         |
   |     REF: SAS/GRAPH AND BASE SAS MAPPING REFERENCE           |
   +-------------------------------------------------------------+*/

/* The LIBNAME statement assigns the library name LOOKUP to the    */
/* location where the Bristish postcodeslookup data resides.       */
/* You must edit the 'file-path' in the following LIBNAME statement*/
/* to reference the lookup data location path designated by your   */
/* installation.                                                   */
libname lookup 'C:\SAS\MapGeocodeData\CodePoint2Geocode';

/* Generate the OFFICES input data set of addresses that the GEOCODE
   procedure uses. Each variable is delimited by a comma. Maximum
   variable lengths are specified. An important step is to remove
   spaces and capitalize the postcode values. */
data offices;
  infile datalines dlm=',';
  length name city $24 postcode $8 country $2; 
  input name                           /* Office name              */
        city                           /* Name of city             */
        postcode                       /* Royal Mail postcode      */
        country;                       /* Two-character country ID */
  postcode=upcase(compress(postcode)); /* Normalize postcodes      */
  state=' ';  /* Not used. Prevents warning from PROC GEOCODE      */
datalines;
Quay Plaza, Manchester, M50 3BA, UK
Wittington House, Buckinghamshire, SL7 2EB, UK
Tara House, Glasgow, G2 1HG, UK
New Broad Street, London, EC2M 1NH, UK
;
run;

/* Run the GEOCODE procedure with the generated OFFICES input data set
   located in the WORK folder. The GEOCODE procedure uses the postcode
   from each address in the input data to match observations in the
   lookup data set. */
proc geocode                      /* Invoke geocoding procedure            */
   method=zip                     /* Specify geocoding method              */
   data=work.offices              /* Input data set of offices             */
   out=geocoded_offices           /* Output data set of locations          */
   lookup=lookup.postcodes        /* Postcode lookup data from MapsOnline  */
   addresszipvar=postcode         /* Postcode variable in input data       */
   lookupzipvar=pc                /* Postcode variable in lookup data      */
   attributevar=(Y_dms            /* Additional variables from lookup data */
                 X_dms);          /* set to assign to geocoded locations   */
run;

/* Print the entire GEOCODED_OFFICES output data set, suppressing the
   observation column. */
proc print data=geocoded_offices(drop=state) noobs;
run;
