 /*+-------------------------------------------------------------+
   |          S A S   S A M P L E   L I B R A R Y                |
   |                                                             |
   |    NAME: GMPGCHOR                                           |
   |   TITLE: GMPGCHOR-Producing a Simple Choropleth Map         |
   | PRODUCT: GRAPH                                              |
   |  SYSTEM: ALL                                                |
   |    KEYS: GRAPHICS MAPS GMAP                                 |
   |   PROCS: GMAP                                               |
   |    DATA: INTERNAL                                           |
   | SUPPORT: GRAPHICS STAFF                                     |
   |  UPDATE: 25JUL2012                                          |
   |          17APR2019 - Changed 'Create a table' verbiage      |
   |     REF: SAS/GRAPH AND BASE SAS MAPPING REFERENCE           |
   +-------------------------------------------------------------+*/

/* Set the graphics environment. */
goptions reset=all border device=png;

/* Specify the format catalog to search that has the predefined
   ISO alpha2 code. */
%let originalfmtsearch = %sysfunc(getoption(fmtsearch,keyword));
options insert=(fmtsearch=(sashelp.mapfmts));

/* Create a table named demographics using sashelp.demographics as
   the base and change its variables to match GfK variable types
   and lengths. This table is used as the response data set. */
proc sql;
create table demographics(rename=(iso=oiso newiso=iso id=oldid newid=ID)) as
select demo.*, 
put(demo.iso,z3.) as newiso format=$3.,
put(demo.iso,ison2a.) as newid 
from sashelp.demographics as demo
;
alter table demographics
modify ID char(15) label='Alpha2 Country Code';
quit;

/* Define the title and the footnote for the map. */
title1 "Population in Europe";
footnote j=r "This map was drawn using GfK map data.";

/* Produce the choropleth map. */
proc gmap map=mapsgfk.europe(where=(id not in:('SJ' 'TR')))
                data=demographics(where=(cont=93)) all;
id id;
choro pop / cdefault=yellow stat=first;
run;
quit;

/* Reset the graphics environment. */
goptions reset=all;

/* Restore the original FMTSEARCH system option value */
options &originalfmtsearch;
