  /*+----------------------------------------------------------------------+
   |          S A S   S A M P L E   L I B R A R Y                         |
   |                                                                      |
   |    NAME: GMPGCITA                                                    |
   |   TITLE: GMPGCITA- Producing a Choropleth Map Annotating Cities      |
   | PRODUCT: GRAPH                                                       |
   |  SYSTEM: ALL                                                         |
   |    KEYS: GRAPHICS MAPS GMAP CHORO STATISTIC GPROJECT                 |
   |   PROCS: GMAP                                                        |
   |    DATA: INTERNAL                                                    |
   | RELEASE: SAS 9.4M7 and prior releases                                |
   |                                                                      |
   | SUPPORT: GRAPHICS STAFF                           CREATED: 30JUL2012 |
   | UPDATED: 07DEC2021 - Enlarged city names                             |
   |     REF: SAS/GRAPH AND BASE SAS MAPPING REFERENCE                    |
   +----------------------------------------------------------------------+*/

/* Set the graphics environment. */
goptions reset=all border device=png;

/* Specify the countries to map. */
data all;
length name $18;
set mapsgfk.austria(in=k1) mapsgfk.czech_republic(in=k2) mapsgfk.hungary;

if k1 then name='Austria';
else if k2 then name='Czech Republic';
else name='Hungary';
run;

/* Project the map and store the projection parameters. */
proc gproject data=all out=map degrees latlong eastlong parmout;
id name id;
run;

/* Create the CITIES data set specifying cities to label (Annotate). */
data cities;
set mapsgfk.world_cities(where=(rank=1 and isoname
   in:('Austria' 'Czech' 'Hung')));
run;

/* Project the annotation data set using the projection parameters stored
   in the prior map projection. */
proc gproject data=cities out=cities latlong eastlong degrees 
 parmin=projparm parmentry=map dupok;
id;
run;

/* Add Annotate variables and markers to the CITIES data set. */
data anno_cities; 
   length color $15 text $55 color $15 style $18; 
   retain function 'label' xsys ysys '2' hsys '3' when 'a'; 
   set cities; 
   text='V'; 
   style='marker'; 
   color='darkslategrey'; 
   size=2.8; 
   position='5'; 
   output; 
   text='  '||trim(left(city)); 
   position='2';
   size=3; 
   style='Arial/Bold'; 
   color='black'; 
   if city in ('Liberec' 'Ostrav') then position='E';
   if city in ('Olomouc' 'Szekesfehervar' 'Graz') then position='1';
   if city in ('Inns' 'Szek' 'Kecs' 'Salz') then position='6';
   if city eq 'Miskolc' then position='1';
   if city in ('Nyiregyhaza' 'Debrecen' 'Brno') then position='E';
   output;
run;

/* Define the title, footnote, and legend for the map. */
title1 ls=1.5 "Annotating Cities"; 
footnote j=r "This map was drawn using GfK map data.";
legend1 label=("Country Name:");

/* Produce the choropleth map that annotates cities in 3 European
   countries. */
proc gmap data=map map=map anno=anno_cities;
   id id;
   choro name / coutline=grayC0
                des='' 
                name='eursub' 
                stat=first
                legend=legend1;
run;
quit;

/* Reset the graphics environment. */
goptions reset=all;
