 /*+-------------------------------------------------------------+
   |          S A S   S A M P L E   L I B R A R Y                |
   |                                                             |
   |    NAME: GMPGMDPT                                           |
   |   TITLE: GMPGMDPT-Specifying Midpoints in a Prism Map       |
   | PRODUCT: GRAPH                                              |
   |  SYSTEM: ALL                                                |
   |    KEYS: GRAPHICS MAPS GMAP PRISM                           |
   |   PROCS: GMAP                                               |
   |    DATA: INTERNAL                                           |
   |                                                             |
   | SUPPORT: GRAPHICS STAFF                                     |            
   |  UPDATE: 06MAR2013 - Removed decimal point from percentages |
   |            in legend                                        |
   |          17APR2019 - Changed 'Create a table' verbiage      |
   |     REF: SAS/GRAPH AND BASE SAS MAPPING REFERENCE           |
   +-------------------------------------------------------------+*/

/* Set the graphics environment. */
goptions reset=all border device=png;

/* Specify the format catalog to search that has the predefined
   ISO alpha2 code. */
%let originalfmtsearch = %sysfunc(getoption(fmtsearch,keyword));
options insert=(fmtsearch=(sashelp.mapfmts));

/* Create a table named demographics using sashelp.demographics
   as the base and change its variables to match GfK variable
   types and lengths. This table is used as the response data
   set. */
proc sql;
create table demographics(rename=(iso=oiso newiso=iso id=oldid newid=ID)) as
select demo.*,
put(demo.iso,z3.) as newiso format=$3.,
put(demo.iso,ison2a.) as newid
from sashelp.demographics as demo
;
alter table demographics
modify ID char(15) label='Alpha2 Country Code';
quit;

/* Define the title and footnote for the map. */
title1 "Adult Literacy Rate";
footnote1 j=r "This map was drawn using GfK map data."; 

/* Produce the prism map. */
proc gmap data=demographics(where=(cont=94))
map=mapsgfk.africa(where=(lake=0)) density=low all;
id id;
format adultliteracypct percentn5.0;
prism adultliteracypct / midpoints=.10 to .90 by .20
                         cdefault=yellow;
run;
quit;

/* Reset the graphics environment. */
goptions reset=all;

/* Restore the original FMTSEARCH system option value. */
options &originalfmtsearch;
