 /*+-------------------------------------------------------------+
   |          S A S   S A M P L E   L I B R A R Y                |
   |                                                             |
   |    NAME: GMPMIDPT                                           |
   |   TITLE: GMPMIDPT-Specifying Midpoints in a Prism Map When  |
   |          Using Traditional Map Data                         |
   | PRODUCT: GRAPH                                              |
   |  SYSTEM: ALL                                                |
   |    KEYS: GRAPHICS MAPS GMAP PRISM                           |
   |   PROCS: GMAP                                               |
   |    DATA: INTERNAL                                           |
   |                                                             |
   | SUPPORT: GRAPHICS STAFF                                     |
   |  UPDATE: 06MAR2013 - Removed decimal point from percentages |
   |             in legend                                       |
   |     REF: SAS/GRAPH AND BASE SAS MAPPING REFERENCE           |
   +-------------------------------------------------------------+*/

/* Set the graphics environment. */
goptions border;

/* Define the title for the map. */
title1 "Adult Literacy Rate";

/* Identify lake regions in the map data set. */
data africa;
set mapssas.africa;
by id segment;
if first.id then lake=0;
if x=. then lake+1;
retain lake;
run;

/* Produce the prism map. */
proc gmap data=sashelp.demographics(where=(cont=94))
          map=africa(where=(lake=0)) density=low all;
   id id;
   format adultliteracypct percentn5.0;
   prism adultliteracypct / midpoints=.1 to .9 by .2
                            cdefault=yellow;
run;
quit;

/* Reset the graphics environment. */
goptions reset=all;
