 /*+-------------------------------------------------------------+
   |          S A S   S A M P L E   L I B R A R Y                |
   |                                                             |
   |    NAME: GRMUSMAP                                           |
   |   TITLE: GRMUSMAP-Removing State Boundaries from U.S. Map   |
   |          Using Traditional Map Data                         |
   | PRODUCT: GRAPH                                              |
   |  SYSTEM: ALL                                                |
   |    KEYS: GRAPHICS GOPTIONS GMAP GREMOVE MAPS PATTERN        |
   |   PROCS: GMAP GREMOVE SORT                                  |
   |    DATA: EXTERNAL                                           |
   |                                                             |
   | SUPPORT: GRAPHICS STAFF                                     |
   |  UPDATE: 02NOV2007                                          |
   |          01NOV2019 - Use the region from sashelp.us_data vs.|
   |             hardcoding                                      |
   |     REF: SAS/GRAPH AND BASE SAS MAPPING REFERENCE           |
   +-------------------------------------------------------------+*/

/* Set the graphics environment. */
goptions border;

/* Create data set MYMAP. */
data mymap; 
   set mapssas.us;
   original_order=_n_;
run;

/* Create data set MYREGIONMAP. */
proc sql noprint;
   create table myregionmap as
   select mymap.*, us_data.region
   from mymap left join sashelp.us_data
   on mymap.statecode=us_data.statecode
   order by region, statecode, original_order;
run;

/* Remove interior boundaries within regions. */
proc gremove data=myregionmap out=myregionmap;
   by region;
   id statecode;
run;

/* Define the title for the map. */
title "U.S. State Map";

/* Define the state pattern characteristics. */
pattern value=s color=white;

/* Show the original map. */
proc gmap map=mapssas.us data=mapssas.us all;
   id state;
   choro segment / stat=first levels=1 nolegend des='' name="grmusmaA";
run;

/* Define the new title for the map with state boundaries
   removed. */
title "U.S. Region Map";

/* Reset the pattern to use the default color pattern before
   creating the map with state boundaries removed. */
goptions reset=pattern;

/* Show the regional map. */
proc gmap map=myregionmap data=sashelp.us_data all;
   id region;
   choro region / stat=first cdefault=red des='' name="grmusmaB";
run;
quit;

/* Reset the graphics environment. */
goptions reset=all;
