 /*+---------------------------------------------------------------------+
   |          S A S   S A M P L E   L I B R A R Y                        |
   |    NAME: SGMPGGRA                                                   |
   |   TITLE: SGMPGGRA Adding a Gradient Legend Showing Population       |
   |                                                                     |
   | PRODUCT: BASE                                                       |
   |  SYSTEM: ALL                                                        |
   |    KEYS: GRAPHICS CHOROMAP SGMAP BUBBLE OSM                         |
   |   PROCS: SGMAP                                                      |
   |    DATA: INTERNAL                                                   |
   | RELEASE: SAS 9.4M7 and prior releases                               |
   |                                                                     |
   | SUPPORT: GRAPHICS STAFF                  CREATED: AUG2022           |
   |     REF: SAS/GRAPH AND BASE SAS MAPPING REFERENCE                   |
   +---------------------------------------------------------------------+*/

/* Define the graphics environment. */
ods graphics / border outputfmt=png;

/* The CHOROMAP statement plots the X (longitude) and Y (latitude)
   variables from the MAPSGFK.US_STATES data set that contains unprojected
   latitude and longitude values. */
data states;
   set mapsgfk.us_states;
   if state ^in(2,15,72);
run;

/* Create the plot data, used by the SGMAP procedure statement and the
   TEXT statement. */
data plot_data; 
   set mapsgfk.uscenter;
   if state ^in(2,15,72) and ocean^='Y';
   statename = fipstate(state);
run;

/* Assign a title to the graph. */
title 'Population from 2010 US Census';

/* Create the graph. */
proc sgmap mapdata=states
   maprespdata=sashelp.us_data
   plotdata=plot_data;
   esrimap
   url='https://services.arcgisonline.com/arcgis/rest/services/
Canvas/World_Light_Gray_Base';
   choromap population_2010 / mapid=state density=2
      name='choro';
   text x=long y=lat text=statename /
      textattrs=(size=6pt);
   gradlegend 'choro' / title='2010 Population' extractscale;
run;

/* Reset the graphics environment */
ods graphics / reset;
title;
