 /*+---------------------------------------------------------------------+ 
   |          S A S   S A M P L E   L I B R A R Y                        | 
   |    NAME: SGMPNVBU                                                   | 
   |   TITLE: SGMPNVBU Nevada County Seat Populations-Bubble Plot        | 
   |                                                                     | 
   |  PRODUCT: BASE                                                      | 
   |  SYSTEM: ALL                                                        | 
   |    KEYS: GRAPHICS CHOROMAP SGMAP BUBBLE                             | 
   |   PROCS: SGMAP                                                      | 
   |    DATA: INTERNAL                                                   |
   | RELEASE: SAS 9.4M5 and later releases                               |   
   |                                                                     | 
   | SUPPORT: GRAPHICS STAFF                 CREATED: AUG2017            |
   |     REF: SAS/GRAPH AND BASE SAS MAPPING REFERENCE                   | 
   +---------------------------------------------------------------------+*/ 
 
/* Set the graphics environment */ 
   ods graphics / imagename='bubble_nevada' imagefmt=png width=5.5in
      height=4.2in; 
 
/* Plot BUBBLES as county seat populations and 
      map polygons are Nevada county boundaries. Retrieve all Nevada
      city locations. 
  Note: 
      You cannot plot these existing X/Y values with 
      the X/Y values in the county map data used below 
      because the two data sets use different projections. 
      The city bubbles would not align with the 
      county boundaries. 
      Avoid this by plotting the unprojected LONG/LAT values. 
      Rename LONG/LAT variables to be X/Y. */ 
data city_xy (label='Nevada Cities' 
             keep=county city city2 x y county_name); 
  set mapsgfk.uscity_all(where=(state=32) drop=x y 
                         rename=(long=x lat=y)); 
run; 
 
proc sort data=city_xy; 
 by city2; 
run; 
 
/* Create population response data for city bubbles. */ 
data city_pop (label='Nevada County Seat Populations'); 
  length city $65 city2 $55; 
  infile datalines dlm=','; 
  input city population_city county; 
  label city            = 'County Seat' 
        city2           = 'Normalized city name' 
        population_city = 'City Population' 
        county          = 'County FIPS Code'; 
  city2 = upcase(compress(city)); 
cards; 
Fallon, 8458, 1 
Las Vegas, 623747, 3 
Minden, 3180, 5 
Elko, 20279, 7 
Goldfield, 443, 9 
Eureka, 487, 11 
Winnemucca, 7887, 13 
Battle Mountain, 3276, 15 
Pioche, 911, 17 
Yerington, 3064, 19 
Hawthorne, 3095, 21 
Tonopah, 2360 , 23 
Lovelock, 1878, 27 
Virginia City, 717, 29 
Reno, 241445, 31 
Ely, 4134, 33 
Carson City, 54521, 510 
; 
 
proc sort data=city_pop; 
  by city2; 
run; 
 
/* Combine city locations with population 
    response data for bubbles. 
    Keep only the county seats. */ 
data city_pop_xy; 
  merge city_pop (in=a) city_xy; 
  by city2; 
  if a; 
run; 
 
/* Retrieve the Nevada county boundaries 
   for the choropleth map. */ 
data nevada; 
set mapsgfk.us_counties(where=(state=32) 
                          drop=x y 
                          rename=(long=x lat=y)); 
run; 
 
/* Generate the title, map, and the legend. */ 
title; 
proc sgmap mapdata=nevada /* Map polygon geometry */ 
        /* Bubble response & location data */ 
        plotdata=city_pop_xy 
       /* Bubble description */ 
        des='Nevada'; 
  title 'Nevada County Seat Populations'; 
  choromap / mapid=county; 
  bubble x=x y=y size=population_city / 
             name='cities' datalabel=city 
             datalabelattrs=(color=darkred 
                                      size=9 
                                      style=italic); 
keylegend 'cities'; 
run; 
 
/* Reset the graphics environment */
ods graphics / reset;
title;
