 /*+---------------------------------------------------------------------+
   |          S A S   S A M P L E   L I B R A R Y                        |
   |    NAME: SGMPURL                                                    |
   |   TITLE: SGMPURL  U.S. State Map with Active URL Links              |
   |                                                                     |
   | PRODUCT: BASE                                                       |
   |  SYSTEM: ALL                                                        |
   |    KEYS: GRAPHICS CHOROMAP SGMAP URL=                               |
   |   PROCS: SGMAP                                                      |
   |    DATA: INTERNAL                                                   |
   | RELEASE: SAS 9.4M8 and later releases                               |
   |    MISC: For SAS 9.4M7 and prior releases, use the 2010 census data |
   |          instead of the 2020 data.                                  |
   |                                                                     |
   | SUPPORT: GRAPHICS STAFF                   CREATED: NOV2019          |
   |     REF: SAS/GRAPH AND BASE SAS MAPPING REFERENCE                   |
   +---------------------------------------------------------------------+*/

/* Specify the graphics options. */
ods graphics / 
   imagemap
   width=580px height=460px
   drilltarget="_blank";
   
/* Assign a title to the graph. */
title1 h=16pt "Click a State to Find Its Home Page";

/* Create the response data set of URLs. */
data my_data; 
set sashelp.us_data;
length my_link $100;
my_link='https://www.google.com/search?q=state+page+for+ '||trim(left(statename));
run;

/* Generate the choropleth U.S. map with hot links.
   Note: For SAS 9.4M7 and earlier releases, use the 2010 census data in the
   CHOROMAP statement instead of the 2020 data.*/
proc sgmap maprespdata=my_data mapdata=mapsgfk.us noautolegend;
choromap population_2020 / 
         mapid=statecode 
         id=statecode 
         url=my_link
         tip=(statename population_2020)
         tiplabel=("State" "Population");
run;
quit;

/* Reset the graphics environment */
ods graphics / reset;
title;
